﻿© 2007 Fluke Corporation, All rights reserved               MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub WR6000 (1 yr) BW VER IEEE /5800
DATE:                  2007-10-03 08:01:07
AUTHOR:                Fluke
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       9
NUMBER OF LINES:       290
CONFIGURATION:         Fluke 5800A
=============================================================================
#
#  Procedure Author:
#        DFM, DAC
#
#  Model(s) Covered:
#        WaveRunner 6030, 6050 and 6051
#
#  Compatibility:
#        MET/CAL 7.20 or later
#
#  Subprocedures:
#        None
#
#  Required Files:
#        None
#
#  Additional Equipment Required:
#        None
#
#  Global Variables Used:
#
#    @Chan
#      This register specifies which channel of the WaveRunner 6000 series
#      oscilloscope is currently being tested.
#        @Chan = 1 (Channel 1)
#        @Chan = 2 (Channel 2)
#        @Chan = 3 (Channel 3)
#        @Chan = 4 (Channel 4)
#        @Chan = 5 (EXT input)
#
#    @NumChan
#      This register specifies the number of channels the WaveRunner 6000
#      series oscilloscope has.
#
#    @BW_MHz
#      This register specifies the Bandwidth of the WaveRunner 6000 series
#      oscilloscope being tested.
#
#    @Ch1 - @Ch4
#      Trace On/Off information as determined in sub, "Sub WaveRunner 6000
#      Select Channel".
#
#  The copyright in this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# The following 5800 statement is only present to force the 5800
# CONFIGURATION: line to include the "S6" (5800/600) attribute.
  1.001  IF           0
  1.002  5800         500MH                        1Vpp           LS S6 S  L
  1.003  ENDIF

  1.004  ASK-                              U

  1.005  RSLT         =
  1.006  RSLT         =Channel [V @Chan]
  1.007  RSLT         =
  1.008  TARGET
  1.009  IEEE2        PACL;C1:TRA [V @Ch1];C2:TRA [V @Ch2]

  1.010  IF           @NumChan == 4
  1.011  IEEE2        C3:TRA [V @Ch3];C4:TRA [V @Ch4]
  1.012  ENDIF

  1.013  IEEE2        C[V @Chan]:CPL D50;OFST 0V
# Trigger Select, Edge, Source, <selected channel>, Trig Slope, +, DC.
  1.014  MATH         L[1] = @Chan
  1.015  IEEE2        TRSE EDGE,SR,C[L1];C[L1]:TRSL POS;TRCP DC;TRLV 0V
# Trigger Mode to Auto.
  1.016  IEEE2        TRMD AUTO
# Sample size to 100k
  1.017  IEEE2        MSIZ 100K
# Set Up Reading Used.
  1.018  IEEE2        CRMS CUST
# Set UUT "Cursor Measure" to "Custom," turn parameter STATistics on.
  1.019  IEEE2        CRMS CUST,STAT
# Clear all current parameter data.
  1.020  IEEE2        PACL
# Parameter Custom, column 1, standard deviation.
  1.021  IEEE2        PACU 1,PKPK,C[V @Chan]
# Begin 10 mV/div bandwidth tests...
  1.022  HEAD         CH[V @Chan] BANDWIDTH TEST: {10 mV/div}
# Set UUT trigger source to line.
  1.023  IEEE2        TRSE EDGE,SR,LINE
# Set UUT time/div. to 50 ns.
  1.024  IEEE2        TDIV 50e-9
# Set UUT specified channel to 10mV/div.
  1.025  IEEE2        C[V @Chan]:VDIV 10e-3
# Establish nominal (mVpp) value; place in MEM for use in next 5800 FSC.
  1.026  MATH         VppNom = 60 ; MEM = VppNom

# Loop to adjust 5800 until 60 mVpp value obtained on UUT.
  1.027  DO
# Initialize 5800 output at nominal value (in MEM).
  1.028  5800         mVpp                         10MH           LS S6 S  L
# Following execution of 5800 statement, copy programmed output to Vpp.
  1.029  MATH         Vpp = MEM1
# Clear sweeps and start measurement sequence in UUT.
  1.030  IEEE2        CLSW
  1.031  WAIT         -t 3 Adjusting 5800 output for 6 division reference...
# Query UUT measured RMS value.
  1.032  IEEE         PAVA? PKPK[I$]
# Extract RMS value and convert to mVpp.
  1.033  MATH         VppMeas = FLD(MEM2, 2, ",") / 1E-3
# Subtract measured from nominal value; Add nominal to compute new value.
  1.034  MATH         MEM = VppNom + (Vpp - VppMeas)
# If measured value is within 0.2 mV of desired (60 mVpp), continue with test.
  1.035  UNTIL        ABS(VppNom - VppMeas) <= 1

  1.036  IF           (@BW_MHz == 350)
  1.037  HEAD         CH[V @Chan] BANDWIDTH TEST (10 mV/div) @ 350.1 MHz
# Set calibrator output to reference voltage set above.
  1.038  MATH         MEM = Vpp
  1.039  5800         mVpp                         350.1MH        LS S6 S  L
# Clear sweeps to begin taking measurements.
  1.040  IEEE2        CLSW
# Wait 3 seconds to allow UUT to gather measurements.
  1.041  WAIT         -t 3 Making UUT Bandwidth measurements...
# Query UUT parameter statistics, average value.
  1.042  IEEE         PAVA? PKPK[I$]
# Delay to ensure bus transaction completed.
  1.043  WAIT         [D500]
# Parse numeric data from returned string and convert from Vrms to mVpp.
  1.044  MATH         MEM = FLD(MEM2, 2, ",") / 1E-3
# Calculate ratio of value at bandwidth tested and convert to dB, and format.
  1.045  MATH         MEM2 = FMT(20 * LOG(MEM / Vpp), "%3.1f")
# If computed dB value >= -3, pass; display value in results.
  1.046  EVAL   -e (MEM2 >= -3) :[32][MEM2] dB @ 350.1 MHz
  2.001  ELSEIF       (@BW_MHz == 500)
  2.002  HEAD         CH[V @Chan] BANDWIDTH TEST (10 mV/div) @ 500.1 MHz
  2.003  TARGET       -p
  2.004  MATH         MEM = Vpp
  2.005  5800         mVpp                         500.1MH        LS S6 S  L
  2.006  IEEE2        CLSW
  2.007  WAIT         -t 3 Making UUT Bandwidth measurements...
  2.008  IEEE         PAVA? PKPK[I$]
  2.009  WAIT         [D500]
  2.010  MATH         MEM = FLD(MEM2, 2, ",") / 1E-3
  2.011  MATH         MEM2 = FMT(20 * LOG(MEM / Vpp), "%3.1f")
  2.012  EVAL   -e (MEM2 >= -3) :[32][MEM2] dB @ 500.1 MHz
  3.001  ENDIF

# Begin 50 mV/div bandwidth tests...
  3.002  RSLT         =
  3.003  HEAD         CH[V @Chan] BANDWIDTH TEST: {50 mV/div}
  3.004  TARGET
  3.005  IEEE2        C[V @Chan]:VDIV 50e-3
  3.006  MATH         VppNom = 300 ; MEM = VppNom

  3.007  DO
  3.008  5800         mVpp                         10MH           LS S6 S  L
  3.009  MATH         Vpp = MEM1
  3.010  IEEE2        CLSW
  3.011  WAIT         -t 3 Adjusting 5800 output for 6 division reference...
  3.012  IEEE         PAVA? PKPK[I$]
  3.013  WAIT         [D500]
  3.014  MATH         VppMeas = FLD(MEM2, 2, ",") / 1E-3
  3.015  MATH         MEM = VppNom + (Vpp - VppMeas)
  3.016  UNTIL        ABS(VppNom - VppMeas) <= 5

  3.017  IF           (@BW_MHz == 350)
  3.018  HEAD         CH[V @Chan] BANDWIDTH TEST (50 mV/div) @ 350.1 MHz
  3.019  MATH         MEM = Vpp
  3.020  5800         mVpp                         350.1MH        LS S6 S  L
  3.021  IEEE2        CLSW
  3.022  WAIT         -t 3 Making UUT Bandwidth measurements...
  3.023  IEEE         PAVA? PKPK[I$]
  3.024  WAIT         [D500]
  3.025  MATH         MEM = FLD(MEM2, 2, ",") / 1E-3
  3.026  MATH         MEM2 = FMT(20 * LOG(MEM / Vpp), "%3.1f")
  3.027  EVAL   -e (MEM2 >= -3) :[32][MEM2] dB @ 350.1 MHz
  4.001  ELSEIF       (@BW_MHz == 500)
  4.002  HEAD         CH[V @Chan] BANDWIDTH TEST (50 mV/div) @ 500.1 MHz
  4.003  TARGET       -p
  4.004  MATH         MEM = Vpp
  4.005  5800         mVpp                         500.1MH        LS S6 S  L
  4.006  IEEE2        CLSW
  4.007  WAIT         -t 3 Making UUT Bandwidth measurements...
  4.008  IEEE         PAVA? PKPK[I$]
  4.009  WAIT         [D500]
  4.010  MATH         MEM = FLD(MEM2, 2, ",") / 1E-3
  4.011  MATH         MEM2 = FMT(20 * LOG(MEM / Vpp), "%3.1f")
  4.012  EVAL   -e (MEM2 >= -3) :[32][MEM2] dB @ 500.1 MHz
  5.001  ENDIF

# Begin 100 mV/div bandwidth tests...
  5.002  RSLT         =
  5.003  HEAD         CH[V @Chan] BANDWIDTH TEST: {100 mV/div}
  5.004  TARGET
  5.005  IEEE2        C[V @Chan]:VDIV 100e-3
  5.006  MATH         VppNom = 600 ; MEM = VppNom

  5.007  DO
  5.008  5800         mVpp                         10MH           LS S6 S  L
  5.009  MATH         Vpp = MEM1
  5.010  IEEE2        CLSW
  5.011  WAIT         -t 3 Adjusting 5800 output for 6 division reference...
  5.012  IEEE         PAVA? PKPK[I$]
  5.013  WAIT         [D500]
  5.014  MATH         VppMeas = FLD(MEM2, 2, ",") / 1E-3
  5.015  MATH         MEM = VppNom + (Vpp - VppMeas)
  5.016  UNTIL        ABS(VppNom - VppMeas) <= 10

  5.017  IF           (@BW_MHz == 350)
  5.018  HEAD         CH[V @Chan] BANDWIDTH TEST (100 mV/div) @ 350.1 MHz
  5.019  MATH         MEM = Vpp
  5.020  5800         mVpp                         350.1MH        LS S6 S  L
  5.021  IEEE2        CLSW
  5.022  WAIT         -t 3 Making UUT Bandwidth measurements...
  5.023  IEEE         PAVA? PKPK[I$]
  5.024  WAIT         [D500]
  5.025  MATH         MEM = FLD(MEM2, 2, ",") / 1E-3
  5.026  MATH         MEM2 = FMT(20 * LOG(MEM / Vpp), "%3.1f")
  5.027  EVAL   -e (MEM2 >= -3) :[32][MEM2] dB @ 350.1 MHz
  6.001  ELSEIF       (@BW_MHz == 500)
  6.002  HEAD         CH[V @Chan] BANDWIDTH TEST (100 mV/div) @ 500.1 MHz
  6.003  TARGET       -p
  6.004  MATH         MEM = Vpp
  6.005  5800         mVpp                         500.1MH        LS S6 S  L
  6.006  IEEE2        CLSW
  6.007  WAIT         -t 3 Making UUT Bandwidth measurements...
  6.008  IEEE         PAVA? PKPK[I$]
  6.009  WAIT         [D500]
  6.010  MATH         MEM = FLD(MEM2, 2, ",") / 1E-3
  6.011  MATH         MEM2 = FMT(20 * LOG(MEM / Vpp), "%3.1f")
  6.012  EVAL   -e (MEM2 >= -3) :[32][MEM2] dB @ 500.1 MHz
  7.001  ENDIF

# Begin 1 V/div bandwidth tests...
  7.002  RSLT         =
  7.003  HEAD         CH[V @Chan] BANDWIDTH TEST: {1 V/div}
  7.004  TARGET
  7.005  IEEE2        C[V @Chan]:VDIV 1
  7.006  MATH         VppNom = 3.2 ; MEM = VppNom

  7.007  DO
  7.008  5800         Vpp                          10MH           LS S6 S  L
  7.009  MATH         Vpp = MEM1
  7.010  IEEE2        CLSW
  7.011  WAIT         -t 3 Adjusting 5800 output for 3.2 division reference...
  7.012  IEEE         PAVA? PKPK[I$]
  7.013  WAIT         [D500]
  7.014  MATH         VppMeas = FLD(MEM2, 2, ",")
  7.015  MATH         MEM = VppNom + (Vpp - VppMeas)
  7.016  UNTIL        ABS(VppNom - VppMeas) <= 100E-3

  7.017  IF           (@BW_MHz == 350)
  7.018  HEAD         CH[V @Chan] BANDWIDTH TEST (1 V/div) @ 350.1 MHz
  7.019  MATH         MEM = Vpp
  7.020  5800         Vpp                          350.1MH        LS S6 S  L
  7.021  IEEE2        CLSW
  7.022  WAIT         -t 3 Making UUT Bandwidth measurements...
  7.023  IEEE         PAVA? PKPK[I$]
  7.024  WAIT         [D500]
  7.025  MATH         MEM = FLD(MEM2, 2, ",")
  7.026  MATH         MEM2 = FMT(20 * LOG(MEM / Vpp), "%3.1f")
  7.027  EVAL   -e (MEM2 >= -3) :[32][MEM2] dB @ 350.1 MHz
  8.001  ELSEIF       (@BW_MHz == 500)
  8.002  HEAD         CH[V @Chan] BANDWIDTH TEST (1 V/div) @ 500.1 MHz
  8.003  TARGET       -p
  8.004  MATH         MEM = Vpp
  8.005  5800         Vpp                          500.1MH        LS S6 S  L
  8.006  IEEE2        CLSW
  8.007  WAIT         -t 3 Making UUT Bandwidth measurements...
  8.008  IEEE         PAVA? PKPK[I$]
  8.009  WAIT         [D500]
  8.010  MATH         MEM = FLD(MEM2, 2, ",")
  8.011  MATH         MEM2 = FMT(20 * LOG(MEM / Vpp), "%3.1f")
  8.012  EVAL   -e (MEM2 >= -3) :[32][MEM2] dB @ 500.1 MHz
  9.001  ENDIF

  9.002  ASK+                              U
  9.003  5800         *                                                 S
  9.004  IEEE2        *RST
  9.005  END
